@@ -36,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.0.10"
+		Version = "v10.0.11"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -90,6 +90,8 @@ func Run() (err error) {
 			Flags: []cli.Flag{
 				&cli.StringFlag{Name: "host", Usage: "host of the relay"},
 				&cli.StringFlag{Name: "ports", Value: "9009,9010,9011,9012,9013", Usage: "ports of the relay"},
+				&cli.IntFlag{Name: "port", Value: 9009, Usage: "base port for the relay"},
+				&cli.IntFlag{Name: "transfers", Value: 5, Usage: "number of ports to use for relay"},
 			},
 		},
 	}
@@ -167,7 +169,7 @@ on the host's process list when passed via the command line. On a
 multi-user system, this could allow other local users to access the
 shared secret and receive the files instead of the intended recipient.
 
-Do you wish to continue to enable the classic mode? (Y/n) `)
+Do you wish to continue to enable the classic mode? (y/N) `)
 				choice := strings.ToLower(utils.GetInput(""))
 				if choice == "y" || choice == "yes" {
 					fmt.Print("\nClassic mode ENABLED.\n\n")
@@ -208,6 +210,14 @@ func setDebugLevel(c *cli.Context) {
 	if c.Bool("debug") {
 		log.SetLevel("debug")
 		log.Debug("debug mode on")
+		// print the public IP address
+		ip, err := utils.PublicIP()
+		if err == nil {
+			log.Debugf("public IP address: %s", ip)
+		} else {
+			log.Debug(err)
+		}
+
 	} else {
 		log.SetLevel("info")
 	}
@@ -385,7 +395,7 @@ you need to set the environmental variable CROC_SECRET:
   export CROC_SECRET="****"
   croc send file.txt
 
-Or you can have the code phrase automaticlaly generated:
+Or you can have the code phrase automatically generated:
 
   croc send file.txt
 	
@@ -668,7 +678,25 @@ func relay(c *cli.Context) (err error) {
 		debugString = "debug"
 	}
 	host := c.String("host")
-	ports := strings.Split(c.String("ports"), ",")
+	var ports []string
+
+	if c.IsSet("ports") {
+		ports = strings.Split(c.String("ports"), ",")
+	} else {
+		portString := c.Int("port")
+		if portString == 0 {
+			portString = 9009
+		}
+		transfersString := c.Int("transfers")
+		if transfersString == 0 {
+			transfersString = 4
+		}
+		ports = make([]string, transfersString)
+		for i := range ports {
+			ports[i] = strconv.Itoa(portString + i)
+		}
+	}
+
 	tcpPorts := strings.Join(ports[1:], ",")
 	for i, port := range ports {
 		if i == 0 {
